==> jc-1.4.0.tar.gz: ppg/PPGError.h <==
// public class ppg.PPGError

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 4b39ee88beeed796 ppg_PPGError

// header file dependencies
// @dep_header java_lang_Throwable

#include "java/lang/Throwable.h"

#ifndef _JC_ppg_PPGError_H_
#define _JC_ppg_PPGError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_PPGError$sub_refs	_jc_ppg_PPGError$sub_refs;
typedef struct _jc_ppg_PPGError$sub_nonrefs	_jc_ppg_PPGError$sub_nonrefs;
typedef struct _jc_ppg_PPGError$refs	_jc_ppg_PPGError$refs;
typedef struct _jc_ppg_PPGError$nonrefs	_jc_ppg_PPGError$nonrefs;
typedef struct _jc_ppg_PPGError$object	_jc_ppg_PPGError$object;

typedef const struct _jc_ppg_PPGError$vmethods	_jc_ppg_PPGError$vmethods;
typedef const struct _jc_ppg_PPGError$vtable	_jc_ppg_PPGError$vtable;
typedef const struct _jc_ppg_PPGError$vtype	_jc_ppg_PPGError$vtype;

// Constructors
extern void _jc_ppg_PPGError$method$_init$84c8bccb0ecf3ee4(_jc_env *, struct _jc_ppg_PPGError$object *, struct _jc_java_lang_String$object *, jint, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_ppg_PPGError$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_ppg_PPGError$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_PPGError$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_ppg_PPGError$vmethods {
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_ppg_PPGError$object *);
};

// Vtable
struct _jc_ppg_PPGError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_ppg_PPGError$vmethods	ppg_PPGError;
};

// Vtype
struct _jc_ppg_PPGError$vtype {
	_jc_type			type;
	_jc_ppg_PPGError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_PPGError$sub_refs {
	struct _jc_java_lang_String$object	*filename;
	struct _jc_java_lang_String$object	*error;
};

// Reference instance fields (object)
struct _jc_ppg_PPGError$refs {
    _jc_ppg_PPGError$sub_refs	ppg_PPGError;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_PPGError$sub_nonrefs {
	jint	line;
};

// Non-reference instance fields (object)
struct _jc_ppg_PPGError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_ppg_PPGError$sub_nonrefs	ppg_PPGError;
};

// Object instance structure
struct _jc_ppg_PPGError$object {
	_jc_ppg_PPGError$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_PPGError$vtype	*vtype;
	_jc_ppg_PPGError$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_PPGError$vtype _jc_ppg_PPGError$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_PPGError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_PPGError$class_object;

#endif	/* _JC_ppg_PPGError_H_ */

==> jc-1.4.6.tar.gz: ppg/PPGError.h <==
// public class ppg.PPGError

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 4b39ee88beeed796 ppg_PPGError

// header file dependencies
// @dep_header java_lang_Throwable

#include "java/lang/Throwable.h"

#ifndef _JC_ppg_PPGError_H_
#define _JC_ppg_PPGError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_PPGError$sub_refs	_jc_ppg_PPGError$sub_refs;
typedef struct _jc_ppg_PPGError$sub_nonrefs	_jc_ppg_PPGError$sub_nonrefs;
typedef struct _jc_ppg_PPGError$refs	_jc_ppg_PPGError$refs;
typedef struct _jc_ppg_PPGError$nonrefs	_jc_ppg_PPGError$nonrefs;
typedef struct _jc_ppg_PPGError$object	_jc_ppg_PPGError$object;

typedef const struct _jc_ppg_PPGError$vmethods	_jc_ppg_PPGError$vmethods;
typedef const struct _jc_ppg_PPGError$vtable	_jc_ppg_PPGError$vtable;
typedef const struct _jc_ppg_PPGError$vtype	_jc_ppg_PPGError$vtype;

// Constructors
extern void _jc_ppg_PPGError$method$_init$84c8bccb0ecf3ee4(_jc_env *, struct _jc_ppg_PPGError$object *, struct _jc_java_lang_String$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_ppg_PPGError$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_ppg_PPGError$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_PPGError$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_ppg_PPGError$vmethods {
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_ppg_PPGError$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_PPGError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_ppg_PPGError$vmethods	ppg_PPGError;
};

// Vtype
struct _jc_ppg_PPGError$vtype {
	_jc_type			type;
	_jc_ppg_PPGError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_PPGError$sub_refs {
	struct _jc_java_lang_String$object	*filename;
	struct _jc_java_lang_String$object	*error;
};

// Reference instance fields (object)
struct _jc_ppg_PPGError$refs {
    _jc_ppg_PPGError$sub_refs	ppg_PPGError;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_PPGError$sub_nonrefs {
	jint	line;
};

// Non-reference instance fields (object)
struct _jc_ppg_PPGError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_ppg_PPGError$sub_nonrefs	ppg_PPGError;
};

// Object instance structure
struct _jc_ppg_PPGError$object {
	_jc_ppg_PPGError$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_PPGError$vtype	*vtype;
	_jc_ppg_PPGError$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_PPGError$vtype _jc_ppg_PPGError$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_PPGError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_PPGError$class_object;

#endif	/* _JC_ppg_PPGError_H_ */
